ThemedButtonStyle enum

ThemedButtonStyle is used to define the style of the button.

The styles are based on Material 3 rules. For more info go to https://m3.material.io/components/all-buttons.

Inheritance
Available extensions

Values

elevated → const ThemedButtonStyle

.elevated refers to a button with a filled background and a shadow. The shadow is generated using the helper function generateContainerElevation with an elevation of 1.

elevatedFab → const ThemedButtonStyle

.elevatedFab refers to a button with a filled background and a shadow. The shadow is generated using the helper function generateContainerElevation with an elevation of 1.

filled → const ThemedButtonStyle

.filled refers to a button with a filled background. Works similar as a .elevated but without the shadow.

filledFab → const ThemedButtonStyle

.filledFab refers to a button with a filled background. Works similar as a .elevatedFab but without the shadow.

filledTonal → const ThemedButtonStyle

.filledTonal refers to a button with a filled background with an constant opacity of 0.2.

filledTonalFab → const ThemedButtonStyle

.filledTonalFab refers to a button with a filled background with an constant opacity of 0.2.

outlined → const ThemedButtonStyle

.outlined refers to a button with a outlined border. The border color is the same as the text color.

outlinedFab → const ThemedButtonStyle

.outlinedFab refers to a button with a outlined border. The border color is the same as the text color.

text → const ThemedButtonStyle

.text refers to a button with a transparent background.

fab → const ThemedButtonStyle

.fab refers to a button with a transparent background.

outlinedTonal → const ThemedButtonStyle

.outlinedTonal refers to a button with a outlined border with an constant opacity of 0.2.

outlinedTonalFab → const ThemedButtonStyle

.outlinedTonalFab refers to a button with a outlined border with an constant opacity of 0.2.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ThemedButtonStyle>
A constant List of the values in this enum, in order of their declaration.