onSubmitted property

VoidCallback? onSubmitted
final

onSubmitted is the function that will be called when the user submits the field This is useful when you want to perform an action when the user press enter.

Implementation

final VoidCallback? onSubmitted;