ThemedTable2OnTapBehavior enum
ThemedTable2OnTapBehavior defines the default behavior when a cell in the table is tapped.
Values
- none → const ThemedTable2OnTapBehavior
-
none indicates that no action should be taken when a cell is tapped.
- copyToClipboard → const ThemedTable2OnTapBehavior
-
copyToClipboard indicates that the content of the tapped cell should be copied to the clipboard.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ThemedTable2OnTapBehavior> - A constant List of the values in this enum, in order of their declaration.