ThemedTimePicker class
Constructors
ThemedTimePicker ({Key ? key , TimeOfDay ? value , void onChanged (TimeOfDay )?, String ? labelText , Widget ? label , String ? placeholder , String ? prefixText , IconData ? prefixIcon , Widget ? prefixWidget , VoidCallback ? onPrefixTap , Widget ? customChild , bool disabled = false , Map <String , String > translations = const {'actions.cancel' : 'Cancel', 'actions.save' : 'Save', 'layrz.timePicker.hours' : 'Hours', 'layrz.timePicker.minutes' : 'Minutes'} , bool overridesLayrzTranslations = false , String ? pattern , bool use24HourFormat = false , Color hoverColor = Colors.transparent , Color focusColor = Colors.transparent , Color splashColor = Colors.transparent , Color highlightColor = Colors.transparent , BorderRadius borderRadius = const BorderRadius.all(Radius.circular(10)) , List <String > errors = const [] , bool hideDetails = false , bool disableBlink = false , EdgeInsets ? padding })
ThemedTimePicker is a time picker input. It is a wrapper of ThemedTextInput with a time picker.
const
Properties
borderRadius
→ BorderRadius
borderRadius is the border radius of the input. Only will affect when customChild is submitted.
By default, it will use BorderRadius.circular(10).
final
customChild
→ Widget ?
customChild is the custom child of the input.
If it is submitted, the input will be ignored.
final
disableBlink
→ bool
disables blinking animation of the time selectors
final
disabled
→ bool
disabled is the disabled state of the input.
final
errors
→ List <String >
errors is the list of errors of the input.
final
focusColor
→ Color
focusColor is the focus color of the input. Only will affect when customChild is submitted.
By default, it will use Colors.transparent.
final
hashCode
→ int
The hash code for this object.
no setter inherited
hideDetails
→ bool
hideDetails is the state of hiding the details of the input.
final
highlightColor
→ Color
highlightColor is the highlight color of the input. Only will affect when customChild is submitted.
By default, it will use Colors.transparent.
final
hoverColor
→ Color
hoverColor is the hover color of the input. Only will affect when customChild is submitted.
By default, it will use Colors.transparent.
final
key
→ Key ?
Controls how one widget replaces another widget in the tree.
final inherited
label
→ Widget ?
label is the label widget of the input. Avoid submit label and labelText at the same time.
final
labelText
→ String ?
labelText is the label text of the input. Avoid submit label and labelText at the same time.
final
onChanged
→ void Function(TimeOfDay ) ?
onChanged is the callback function when the input is changed.
final
onPrefixTap
→ VoidCallback ?
onPrefixTap is the callback function when the prefix is tapped.
final
overridesLayrzTranslations
→ bool
overridesLayrzTranslations is the flag to override the default translations of Layrz.
final
padding
→ EdgeInsets ?
padding is the padding of the input.
final
pattern
→ String ?
pattern is the pattern of the date. By default, depending of use24HourFormat we use %I:%M %p or %H:%M.
If pattern is submitted, this will be used instead of the default.
final
placeholder
→ String ?
placeholder is the placeholder of the input.
final
prefixIcon
→ IconData ?
prefixIcon is the prefix icon of the input. Avoid submit prefixIcon and prefixWidget at the same time.
final
prefixText
→ String ?
prefixText is the prefix text of the input.
final
prefixWidget
→ Widget ?
prefixWidget is the prefix widget of the input. Avoid submit prefixIcon and prefixWidget at the same time.
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
splashColor
→ Color
splashColor is the splash color of the input. Only will affect when customChild is submitted.
By default, it will use Colors.transparent.
final
translations
→ Map <String , String >
translations is the translations of the input. By default we use LayrzAppLocalizations for translations,
but you can submit your own translations using this property. Consider when LayrzAppLocalizations is present,
is the default value of this property.
Required translations:
final
use24HourFormat
→ bool
use24HourFormat is the flag to use 24 hour format. By default is false, so it will use 12 hour format.
final
value
→ TimeOfDay ?
value is the value of the input.
final