DialogSelectInput<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DialogSelectInput
Constructors
-
DialogSelectInput({Key? key, required BoxConstraints dialogConstraints, required String? labelText, required bool hideTitle, required bool enableSearch, required TextInputType searchKeyboardType, required List<
ThemedSelectItem< items, required double itemExtent, required bool canUnselect, required bool returnNullOnClose, required bool hideButtons, required Map<T> >String, String> translations, required bool overridesLayrzTranslations, required bool autoclose, required ThemedSelectItem<T> ? value, double? overrideHeightDialog}) -
const
Properties
- autoclose → bool
-
final
- canUnselect → bool
-
final
- dialogConstraints → BoxConstraints
-
final
- enableSearch → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideButtons → bool
-
final
- hideTitle → bool
-
final
- itemExtent → double
-
final
-
items
→ List<
ThemedSelectItem< T> > -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelText → String?
-
final
- overrideHeightDialog → double?
-
final
- overridesLayrzTranslations → bool
-
final
- returnNullOnClose → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchKeyboardType → TextInputType
-
final
-
translations
→ Map<
String, String> -
final
-
value
→ ThemedSelectItem<
T> ? -
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DialogSelectInput> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited