ThemedButtonStyle enum
ThemedButtonStyle is used to define the style of the button.
The styles are based on Material 3 rules. For more info go to https://m3.material.io/components/all-buttons.
Values
- elevated → const ThemedButtonStyle
-
.elevatedrefers to a button with a filled background and a shadow. The shadow is generated using the helper functiongenerateContainerElevationwith an elevation of1. - elevatedFab → const ThemedButtonStyle
-
.elevatedFabrefers to a button with a filled background and a shadow. The shadow is generated using the helper functiongenerateContainerElevationwith an elevation of1. - filled → const ThemedButtonStyle
-
.filledrefers to a button with a filled background. Works similar as a.elevatedbut without the shadow. - filledFab → const ThemedButtonStyle
-
.filledFabrefers to a button with a filled background. Works similar as a.elevatedFabbut without the shadow. - filledTonal → const ThemedButtonStyle
-
.filledTonalrefers to a button with a filled background with an constant opacity of0.2. - filledTonalFab → const ThemedButtonStyle
-
.filledTonalFabrefers to a button with a filled background with an constant opacity of0.2. - outlined → const ThemedButtonStyle
-
.outlinedrefers to a button with a outlined border. The border color is the same as the text color. - outlinedFab → const ThemedButtonStyle
-
.outlinedFabrefers to a button with a outlined border. The border color is the same as the text color. - text → const ThemedButtonStyle
-
.textrefers to a button with a transparent background. - fab → const ThemedButtonStyle
-
.fabrefers to a button with a transparent background. - outlinedTonal → const ThemedButtonStyle
-
.outlinedTonalrefers to a button with a outlined border with an constant opacity of0.2. - outlinedTonalFab → const ThemedButtonStyle
-
.outlinedTonalFabrefers to a button with a outlined border with an constant opacity of0.2.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ThemedButtonStyle> - A constant List of the values in this enum, in order of their declaration.